Gorilla's Documentation
=======================

Welcome! If you are just getting started, a recommended first read is the
:ref:`overview` as it shortly covers the *why*, *what*, and *how*'s of this
library. From there, the :ref:`installation` then the :ref:`tutorial` sections
should get you up to speed with the basics required to use it.

Looking how to use a specific function, class, or method? The whole public
interface is described in the :ref:`reference` section.

Please report bugs and suggestions on `GitHub`_.


User's Guide
------------

.. toctree::
   :maxdepth: 2

   overview
   installation
   tutorial
   caution
   reference


Developer's Guide
-----------------

.. toctree::
   :maxdepth: 2

   tests


Additional Information
----------------------

.. toctree::
   :maxdepth: 2

   changelog
   versioning
   license
   out_there


.. testsetup::

   import gorilla


.. _GitHub: https://github.com/christophercrouzet/gorilla
